@@ -17,15 +17,33 @@ limitations under the License.
 package services;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
+import org.ovirt.api.metamodel.annotations.InputDetail;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
 import types.CpuProfile;
 
+import static org.ovirt.api.metamodel.language.ApiLanguage.mandatory;
+import static org.ovirt.api.metamodel.language.ApiLanguage.optional;
+
 @Service
 @Area("Virtualization")
 public interface AssignedCpuProfilesService {
+    /**
+     * Add a new cpu profile for the cluster.
+     *
+     * @author Ori Liel <oliel@redhat.com>
+     * @date 18 Jan 2017
+     * @status added
+     */
     interface Add {
+        @InputDetail
+        default void inputDetail() {
+            mandatory(profile().name());
+            optional(profile().description());
+            optional(profile().qos().id());
+        }
         @In @Out CpuProfile profile();
     }
 
@@ -38,7 +56,7 @@ public interface AssignedCpuProfilesService {
      * @date 15 Apr 2017
      * @status added
      */
-    interface List {
+    interface List extends Follow {
         @Out CpuProfile[] profiles();
 
         /**
