@@ -17,15 +17,34 @@ limitations under the License.
 package services;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
+import org.ovirt.api.metamodel.annotations.InputDetail;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
 import types.DiskProfile;
 
+import static org.ovirt.api.metamodel.language.ApiLanguage.mandatory;
+import static org.ovirt.api.metamodel.language.ApiLanguage.optional;
+
 @Service
 @Area("Storage")
 public interface DiskProfilesService {
+    /**
+     * Add a new disk profile to the system.
+     *
+     * @author Ori Liel <oliel@redhat.com>
+     * @date 18 Jan 2017
+     * @status added
+     */
     interface Add {
+        @InputDetail
+        default void inputDetail() {
+            mandatory(profile().name());
+            mandatory(profile().storageDomain().id());
+            optional(profile().description());
+            optional(profile().qos().id());
+        }
         @In @Out DiskProfile profile();
     }
 
@@ -38,7 +57,7 @@ public interface DiskProfilesService {
      * @date 15 Apr 2017
      * @status added
      */
-    interface List {
+    interface List extends Follow {
         @Out DiskProfile[] profile();
 
         /**
