@@ -17,12 +17,16 @@ limitations under the License.
 package services.externalhostproviders;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
+import org.ovirt.api.metamodel.annotations.InputDetail;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
 import services.ExternalProviderService;
 import types.ExternalHostProvider;
 
+import static org.ovirt.api.metamodel.language.ApiLanguage.optional;
+
 /**
  * Represents an external host provider, such as Foreman or Satellite.
  *
@@ -64,11 +68,26 @@ public interface ExternalHostProviderService extends ExternalProviderService {
      * @date 24 Apr 2017
      * @status added
      */
-    interface Get {
+    interface Get extends Follow {
         @Out ExternalHostProvider provider();
     }
 
+    /**
+     * Update the specified external host provider in the system.
+     *
+     * @author Ori Liel <oliel@redhat.com>
+     * @date 18 Jan 2017
+     * @status added
+     */
     interface Update {
+        @InputDetail
+        default void inputDetail() {
+            optional(provider().description());
+            optional(provider().name());
+            optional(provider().password());
+            optional(provider().requiresAuthentication());
+            optional(provider().username());
+        }
         @In @Out ExternalHostProvider provider();
 
         /**
