@@ -26,6 +26,7 @@ import org.ovirt.engine.sdk4.builders.DiskBuilder;
 import org.ovirt.engine.sdk4.builders.HostBuilder;
 import org.ovirt.engine.sdk4.builders.SnapshotBuilder;
 import org.ovirt.engine.sdk4.builders.StorageDomainBuilder;
+import org.ovirt.engine.sdk4.builders.StorageDomainLeaseBuilder;
 import org.ovirt.engine.sdk4.builders.TicketBuilder;
 import org.ovirt.engine.sdk4.builders.VmBuilder;
 import org.ovirt.engine.sdk4.types.AuthorizedKey;
@@ -34,6 +35,7 @@ import org.ovirt.engine.sdk4.types.Disk;
 import org.ovirt.engine.sdk4.types.Host;
 import org.ovirt.engine.sdk4.types.Snapshot;
 import org.ovirt.engine.sdk4.types.StorageDomain;
+import org.ovirt.engine.sdk4.types.StorageDomainLease;
 import org.ovirt.engine.sdk4.types.Ticket;
 import org.ovirt.engine.sdk4.types.Vm;
 
@@ -757,8 +759,73 @@ public interface VmService extends MeasurableService {
          */
         PreviewSnapshotRequest async(Boolean async);
         PreviewSnapshotRequest disks(List<Disk> disks);
+        /**
+         * Specify the disks included in the snapshot's preview.
+         * 
+         * For each disk parameter, it is also required to specify its `image_id`.
+         * 
+         * For example, to preview a snapshot with identifier `456` which includes a disk with identifier `111` and its
+         * `image_id` as `222`, send a request like this:
+         * 
+         * [source]
+         * ----
+         * POST /ovirt-engine/api/vms/123/previewsnapshot
+         * ----
+         * 
+         * Request body:
+         * 
+         * [source,xml]
+         * ----
+         * <action>
+         *   <disks>
+         *     <disk id="111">
+         *       <image_id>222</image_id>
+         *     </disk>
+         *   </disks>
+         *   <snapshot id="456"/>
+         * </action>
+         * ----
+         */
         PreviewSnapshotRequest disks(Disk... disks);
+        /**
+         * Specify the disks included in the snapshot's preview.
+         * 
+         * For each disk parameter, it is also required to specify its `image_id`.
+         * 
+         * For example, to preview a snapshot with identifier `456` which includes a disk with identifier `111` and its
+         * `image_id` as `222`, send a request like this:
+         * 
+         * [source]
+         * ----
+         * POST /ovirt-engine/api/vms/123/previewsnapshot
+         * ----
+         * 
+         * Request body:
+         * 
+         * [source,xml]
+         * ----
+         * <action>
+         *   <disks>
+         *     <disk id="111">
+         *       <image_id>222</image_id>
+         *     </disk>
+         *   </disks>
+         *   <snapshot id="456"/>
+         * </action>
+         * ----
+         */
         PreviewSnapshotRequest disks(DiskBuilder... disks);
+        PreviewSnapshotRequest lease(StorageDomainLease lease);
+        /**
+         * Specify the lease storage domain ID to use in the preview of the snapshot.
+         * If lease parameter is not passed, then the previewed snapshot lease storage domain will be used.
+         * If lease parameter is passed with empty storage domain parameter, then no lease will be used
+         * for the snapshot preview.
+         * If lease parameter is passed with storage domain parameter then the storage domain ID can be
+         * only one of the leases domain IDs that belongs to one of the virtual machine snapshots.
+         * This is an optional parameter, set by default to `null`
+         */
+        PreviewSnapshotRequest lease(StorageDomainLeaseBuilder lease);
         PreviewSnapshotRequest restoreMemory(Boolean restoreMemory);
         PreviewSnapshotRequest snapshot(Snapshot snapshot);
         PreviewSnapshotRequest snapshot(SnapshotBuilder snapshot);
