@@ -82,7 +82,9 @@ public class DataCenterNetworkServiceImpl extends ServiceImpl implements DataCen
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new GetResponseImpl(XmlNetworkReader.readOne(reader));
+                    GetResponseImpl actionResponse = new GetResponseImpl();
+                    actionResponse.network(XmlNetworkReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -93,7 +95,7 @@ public class DataCenterNetworkServiceImpl extends ServiceImpl implements DataCen
             }
             else {
                 checkFault(response);
-                return new GetResponseImpl(null);
+                return new GetResponseImpl();
             }
         }
         
@@ -102,7 +104,7 @@ public class DataCenterNetworkServiceImpl extends ServiceImpl implements DataCen
     private class GetResponseImpl implements GetResponse {
         private Network network;
         
-        public GetResponseImpl(Network network) {
+        public void network(Network network) {
             this.network = network;
         }
         
@@ -211,7 +213,9 @@ public class DataCenterNetworkServiceImpl extends ServiceImpl implements DataCen
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new UpdateResponseImpl(XmlNetworkReader.readOne(reader));
+                    UpdateResponseImpl actionResponse = new UpdateResponseImpl();
+                    actionResponse.network(XmlNetworkReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -222,7 +226,7 @@ public class DataCenterNetworkServiceImpl extends ServiceImpl implements DataCen
             }
             else {
                 checkFault(response);
-                return new UpdateResponseImpl(null);
+                return new UpdateResponseImpl();
             }
         }
         
@@ -231,7 +235,7 @@ public class DataCenterNetworkServiceImpl extends ServiceImpl implements DataCen
     private class UpdateResponseImpl implements UpdateResponse {
         private Network network;
         
-        public UpdateResponseImpl(Network network) {
+        public void network(Network network) {
             this.network = network;
         }
         
