@@ -43,17 +43,26 @@ import org.ovirt.engine.sdk4.services.ExternalHostsService;
 import org.ovirt.engine.sdk4.services.ExternalProviderCertificatesService;
 import org.ovirt.engine.sdk4.types.ExternalHostProvider;
 
-public class ExternalHostProviderServiceImpl extends ServiceImpl implements ExternalHostProviderService {
+public class ExternalHostProviderServiceImpl extends ExternalProviderServiceImpl implements ExternalHostProviderService {
     
     public ExternalHostProviderServiceImpl(HttpConnection connection, String path) {
         super(connection, path);
     }
     
     private class GetRequestImpl extends BaseRequest<GetRequest, GetResponse> implements GetRequest {
+        private String follow;
+        public GetRequest follow(String follow) {
+            this.follow = follow;
+            return this;
+        }
+        
         public GetResponse send() {
             HttpGet request = null;
             try {
                 URIBuilder uriBuilder = new URIBuilder(getConnection().getUrl() + getPath());
+                if (follow != null) {
+                    uriBuilder.addParameter("follow", XmlWriter.renderString(follow));
+                }
                 if (query != null) {
                     for (Map.Entry<String, String> queryParam : query.entrySet()) {
                         uriBuilder.addParameter(queryParam.getKey(), queryParam.getValue());
@@ -78,7 +87,9 @@ public class ExternalHostProviderServiceImpl extends ServiceImpl implements Exte
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new GetResponseImpl(XmlExternalHostProviderReader.readOne(reader));
+                    GetResponseImpl actionResponse = new GetResponseImpl();
+                    actionResponse.provider(XmlExternalHostProviderReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -89,7 +100,7 @@ public class ExternalHostProviderServiceImpl extends ServiceImpl implements Exte
             }
             else {
                 checkFault(response);
-                return new GetResponseImpl(null);
+                return new GetResponseImpl();
             }
         }
         
@@ -98,7 +109,7 @@ public class ExternalHostProviderServiceImpl extends ServiceImpl implements Exte
     private class GetResponseImpl implements GetResponse {
         private ExternalHostProvider provider;
         
-        public GetResponseImpl(ExternalHostProvider provider) {
+        public void provider(ExternalHostProvider provider) {
             this.provider = provider;
         }
         
@@ -225,7 +236,9 @@ public class ExternalHostProviderServiceImpl extends ServiceImpl implements Exte
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new UpdateResponseImpl(XmlExternalHostProviderReader.readOne(reader));
+                    UpdateResponseImpl actionResponse = new UpdateResponseImpl();
+                    actionResponse.provider(XmlExternalHostProviderReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -236,7 +249,7 @@ public class ExternalHostProviderServiceImpl extends ServiceImpl implements Exte
             }
             else {
                 checkFault(response);
-                return new UpdateResponseImpl(null);
+                return new UpdateResponseImpl();
             }
         }
         
@@ -245,7 +258,7 @@ public class ExternalHostProviderServiceImpl extends ServiceImpl implements Exte
     private class UpdateResponseImpl implements UpdateResponse {
         private ExternalHostProvider provider;
         
-        public UpdateResponseImpl(ExternalHostProvider provider) {
+        public void provider(ExternalHostProvider provider) {
             this.provider = provider;
         }
         
