@@ -23,6 +23,7 @@ import org.apache.http.client.methods.HttpGet;
 import org.apache.http.client.utils.URIBuilder;
 import org.apache.http.util.EntityUtils;
 import org.ovirt.api.metamodel.runtime.xml.XmlReader;
+import org.ovirt.api.metamodel.runtime.xml.XmlWriter;
 import org.ovirt.engine.sdk4.BaseRequest;
 import org.ovirt.engine.sdk4.Error;
 import org.ovirt.engine.sdk4.Service;
@@ -38,10 +39,19 @@ public class TemplateCdromServiceImpl extends ServiceImpl implements TemplateCdr
     }
     
     private class GetRequestImpl extends BaseRequest<GetRequest, GetResponse> implements GetRequest {
+        private String follow;
+        public GetRequest follow(String follow) {
+            this.follow = follow;
+            return this;
+        }
+        
         public GetResponse send() {
             HttpGet request = null;
             try {
                 URIBuilder uriBuilder = new URIBuilder(getConnection().getUrl() + getPath());
+                if (follow != null) {
+                    uriBuilder.addParameter("follow", XmlWriter.renderString(follow));
+                }
                 if (query != null) {
                     for (Map.Entry<String, String> queryParam : query.entrySet()) {
                         uriBuilder.addParameter(queryParam.getKey(), queryParam.getValue());
@@ -66,7 +76,9 @@ public class TemplateCdromServiceImpl extends ServiceImpl implements TemplateCdr
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new GetResponseImpl(XmlCdromReader.readOne(reader));
+                    GetResponseImpl actionResponse = new GetResponseImpl();
+                    actionResponse.cdrom(XmlCdromReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -77,7 +89,7 @@ public class TemplateCdromServiceImpl extends ServiceImpl implements TemplateCdr
             }
             else {
                 checkFault(response);
-                return new GetResponseImpl(null);
+                return new GetResponseImpl();
             }
         }
         
@@ -86,7 +98,7 @@ public class TemplateCdromServiceImpl extends ServiceImpl implements TemplateCdr
     private class GetResponseImpl implements GetResponse {
         private Cdrom cdrom;
         
-        public GetResponseImpl(Cdrom cdrom) {
+        public void cdrom(Cdrom cdrom) {
             this.cdrom = cdrom;
         }
         
