@@ -36,11 +36,13 @@ import org.ovirt.engine.sdk4.BaseRequest;
 import org.ovirt.engine.sdk4.Error;
 import org.ovirt.engine.sdk4.Service;
 import org.ovirt.engine.sdk4.builders.ActionBuilder;
+import org.ovirt.engine.sdk4.builders.AuthorizedKeyBuilder;
 import org.ovirt.engine.sdk4.builders.ClusterBuilder;
 import org.ovirt.engine.sdk4.builders.DiskBuilder;
 import org.ovirt.engine.sdk4.builders.HostBuilder;
 import org.ovirt.engine.sdk4.builders.SnapshotBuilder;
 import org.ovirt.engine.sdk4.builders.StorageDomainBuilder;
+import org.ovirt.engine.sdk4.builders.StorageDomainLeaseBuilder;
 import org.ovirt.engine.sdk4.builders.TicketBuilder;
 import org.ovirt.engine.sdk4.builders.VmBuilder;
 import org.ovirt.engine.sdk4.internal.HttpConnection;
@@ -65,15 +67,17 @@ import org.ovirt.engine.sdk4.services.VmService;
 import org.ovirt.engine.sdk4.services.VmSessionsService;
 import org.ovirt.engine.sdk4.services.VmWatchdogsService;
 import org.ovirt.engine.sdk4.types.Action;
+import org.ovirt.engine.sdk4.types.AuthorizedKey;
 import org.ovirt.engine.sdk4.types.Cluster;
 import org.ovirt.engine.sdk4.types.Disk;
 import org.ovirt.engine.sdk4.types.Host;
 import org.ovirt.engine.sdk4.types.Snapshot;
 import org.ovirt.engine.sdk4.types.StorageDomain;
+import org.ovirt.engine.sdk4.types.StorageDomainLease;
 import org.ovirt.engine.sdk4.types.Ticket;
 import org.ovirt.engine.sdk4.types.Vm;
 
-public class VmServiceImpl extends ServiceImpl implements VmService {
+public class VmServiceImpl extends MeasurableServiceImpl implements VmService {
     
     public VmServiceImpl(HttpConnection connection, String path) {
         super(connection, path);
@@ -394,6 +398,12 @@ public class VmServiceImpl extends ServiceImpl implements VmService {
             return this;
         }
         
+        private String follow;
+        public GetRequest follow(String follow) {
+            this.follow = follow;
+            return this;
+        }
+        
         private Boolean nextRun;
         public GetRequest nextRun(Boolean nextRun) {
             this.nextRun = nextRun;
@@ -410,6 +420,9 @@ public class VmServiceImpl extends ServiceImpl implements VmService {
                 if (filter != null) {
                     uriBuilder.addParameter("filter", XmlWriter.renderBoolean(filter));
                 }
+                if (follow != null) {
+                    uriBuilder.addParameter("follow", XmlWriter.renderString(follow));
+                }
                 if (nextRun != null) {
                     uriBuilder.addParameter("next_run", XmlWriter.renderBoolean(nextRun));
                 }
@@ -437,7 +450,9 @@ public class VmServiceImpl extends ServiceImpl implements VmService {
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new GetResponseImpl(XmlVmReader.readOne(reader));
+                    GetResponseImpl actionResponse = new GetResponseImpl();
+                    actionResponse.vm(XmlVmReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -448,7 +463,7 @@ public class VmServiceImpl extends ServiceImpl implements VmService {
             }
             else {
                 checkFault(response);
-                return new GetResponseImpl(null);
+                return new GetResponseImpl();
             }
         }
         
@@ -457,7 +472,7 @@ public class VmServiceImpl extends ServiceImpl implements VmService {
     private class GetResponseImpl implements GetResponse {
         private Vm vm;
         
-        public GetResponseImpl(Vm vm) {
+        public void vm(Vm vm) {
             this.vm = vm;
         }
         
@@ -667,6 +682,17 @@ public class VmServiceImpl extends ServiceImpl implements VmService {
             return this;
         }
         
+        private StorageDomainLease lease;
+        public PreviewSnapshotRequest lease(StorageDomainLease lease) {
+            this.lease = lease;
+            return this;
+        }
+        
+        public PreviewSnapshotRequest lease(StorageDomainLeaseBuilder lease) {
+            this.lease = lease.build();
+            return this;
+        }
+        
         private Boolean restoreMemory;
         public PreviewSnapshotRequest restoreMemory(Boolean restoreMemory) {
             this.restoreMemory = restoreMemory;
@@ -704,6 +730,7 @@ public class VmServiceImpl extends ServiceImpl implements VmService {
                 ActionBuilder action = new ActionBuilder();
                 action.async(async);
                 action.disks(disks);
+                action.lease(lease);
                 action.restoreMemory(restoreMemory);
                 action.snapshot(snapshot);
                 action.vm(vm);
@@ -946,6 +973,17 @@ public class VmServiceImpl extends ServiceImpl implements VmService {
             return this;
         }
         
+        private AuthorizedKey authorizedKey;
+        public StartRequest authorizedKey(AuthorizedKey authorizedKey) {
+            this.authorizedKey = authorizedKey;
+            return this;
+        }
+        
+        public StartRequest authorizedKey(AuthorizedKeyBuilder authorizedKey) {
+            this.authorizedKey = authorizedKey.build();
+            return this;
+        }
+        
         private Boolean filter;
         public StartRequest filter(Boolean filter) {
             this.filter = filter;
@@ -981,6 +1019,12 @@ public class VmServiceImpl extends ServiceImpl implements VmService {
             return this;
         }
         
+        private Boolean volatile_;
+        public StartRequest volatile_(Boolean volatile_) {
+            this.volatile_ = volatile_;
+            return this;
+        }
+        
         public StartResponse send() {
             HttpPost request = new HttpPost(getConnection().getUrl() + getPath() + "/start");
             try (
@@ -989,11 +1033,13 @@ public class VmServiceImpl extends ServiceImpl implements VmService {
             ) {
                 ActionBuilder action = new ActionBuilder();
                 action.async(async);
+                action.authorizedKey(authorizedKey);
                 action.filter(filter);
                 action.pause(pause);
                 action.useCloudInit(useCloudInit);
                 action.useSysprep(useSysprep);
                 action.vm(vm);
+                action.volatile_(volatile_);
                 XmlActionWriter.writeOne(action.build(), xmlWriter);
                 xmlWriter.flush();
                 request.setEntity(new ByteArrayEntity(output.toByteArray()));
@@ -1199,7 +1245,9 @@ public class VmServiceImpl extends ServiceImpl implements VmService {
             HttpResponse response = getConnection().send(request);
             Action action = checkAction(response);
             EntityUtils.consumeQuietly(response.getEntity());
-            return new TicketResponseImpl(action.ticket());
+            TicketResponseImpl actionResponse = new TicketResponseImpl();
+            actionResponse.ticket(action.ticket());
+            return actionResponse;
         }
         
     }
@@ -1207,7 +1255,7 @@ public class VmServiceImpl extends ServiceImpl implements VmService {
     private class TicketResponseImpl implements TicketResponse {
         private Ticket ticket;
         
-        public TicketResponseImpl(Ticket ticket) {
+        public void ticket(Ticket ticket) {
             this.ticket = ticket;
         }
         
@@ -1221,6 +1269,172 @@ public class VmServiceImpl extends ServiceImpl implements VmService {
         return new TicketRequestImpl();
     }
     
+    private class ExportToExportDomainRequestImpl extends BaseRequest<ExportToExportDomainRequest, ExportToExportDomainResponse> implements ExportToExportDomainRequest {
+        private Boolean async;
+        public ExportToExportDomainRequest async(Boolean async) {
+            this.async = async;
+            return this;
+        }
+        
+        private Boolean discardSnapshots;
+        public ExportToExportDomainRequest discardSnapshots(Boolean discardSnapshots) {
+            this.discardSnapshots = discardSnapshots;
+            return this;
+        }
+        
+        private Boolean exclusive;
+        public ExportToExportDomainRequest exclusive(Boolean exclusive) {
+            this.exclusive = exclusive;
+            return this;
+        }
+        
+        private StorageDomain storageDomain;
+        public ExportToExportDomainRequest storageDomain(StorageDomain storageDomain) {
+            this.storageDomain = storageDomain;
+            return this;
+        }
+        
+        public ExportToExportDomainRequest storageDomain(StorageDomainBuilder storageDomain) {
+            this.storageDomain = storageDomain.build();
+            return this;
+        }
+        
+        public ExportToExportDomainResponse send() {
+            HttpPost request = new HttpPost(getConnection().getUrl() + getPath() + "/export");
+            try (
+              ByteArrayOutputStream output = new ByteArrayOutputStream();
+              XmlWriter xmlWriter = new XmlWriter(output, true)
+            ) {
+                ActionBuilder action = new ActionBuilder();
+                action.async(async);
+                action.discardSnapshots(discardSnapshots);
+                action.exclusive(exclusive);
+                action.storageDomain(storageDomain);
+                XmlActionWriter.writeOne(action.build(), xmlWriter);
+                xmlWriter.flush();
+                request.setEntity(new ByteArrayEntity(output.toByteArray()));
+            }
+            catch (IOException ex) {
+                throw new Error("Failed to write request", ex);
+            }
+            
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
+            HttpResponse response = getConnection().send(request);
+            Action action = checkAction(response);
+            EntityUtils.consumeQuietly(response.getEntity());
+            return new ExportToExportDomainResponseImpl();
+        }
+        
+    }
+    
+    private class ExportToExportDomainResponseImpl implements ExportToExportDomainResponse {
+    }
+    
+    public ExportToExportDomainRequest exportToExportDomain() {
+        return new ExportToExportDomainRequestImpl();
+    }
+    
+    private class ExportToPathOnHostRequestImpl extends BaseRequest<ExportToPathOnHostRequest, ExportToPathOnHostResponse> implements ExportToPathOnHostRequest {
+        private Boolean async;
+        public ExportToPathOnHostRequest async(Boolean async) {
+            this.async = async;
+            return this;
+        }
+        
+        private String directory;
+        public ExportToPathOnHostRequest directory(String directory) {
+            this.directory = directory;
+            return this;
+        }
+        
+        private Boolean discardSnapshots;
+        public ExportToPathOnHostRequest discardSnapshots(Boolean discardSnapshots) {
+            this.discardSnapshots = discardSnapshots;
+            return this;
+        }
+        
+        private Boolean exclusive;
+        public ExportToPathOnHostRequest exclusive(Boolean exclusive) {
+            this.exclusive = exclusive;
+            return this;
+        }
+        
+        private String filename;
+        public ExportToPathOnHostRequest filename(String filename) {
+            this.filename = filename;
+            return this;
+        }
+        
+        private Host host;
+        public ExportToPathOnHostRequest host(Host host) {
+            this.host = host;
+            return this;
+        }
+        
+        public ExportToPathOnHostRequest host(HostBuilder host) {
+            this.host = host.build();
+            return this;
+        }
+        
+        private StorageDomain storageDomain;
+        public ExportToPathOnHostRequest storageDomain(StorageDomain storageDomain) {
+            this.storageDomain = storageDomain;
+            return this;
+        }
+        
+        public ExportToPathOnHostRequest storageDomain(StorageDomainBuilder storageDomain) {
+            this.storageDomain = storageDomain.build();
+            return this;
+        }
+        
+        public ExportToPathOnHostResponse send() {
+            HttpPost request = new HttpPost(getConnection().getUrl() + getPath() + "/export");
+            try (
+              ByteArrayOutputStream output = new ByteArrayOutputStream();
+              XmlWriter xmlWriter = new XmlWriter(output, true)
+            ) {
+                ActionBuilder action = new ActionBuilder();
+                action.async(async);
+                action.directory(directory);
+                action.discardSnapshots(discardSnapshots);
+                action.exclusive(exclusive);
+                action.filename(filename);
+                action.host(host);
+                action.storageDomain(storageDomain);
+                XmlActionWriter.writeOne(action.build(), xmlWriter);
+                xmlWriter.flush();
+                request.setEntity(new ByteArrayEntity(output.toByteArray()));
+            }
+            catch (IOException ex) {
+                throw new Error("Failed to write request", ex);
+            }
+            
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
+            HttpResponse response = getConnection().send(request);
+            Action action = checkAction(response);
+            EntityUtils.consumeQuietly(response.getEntity());
+            return new ExportToPathOnHostResponseImpl();
+        }
+        
+    }
+    
+    private class ExportToPathOnHostResponseImpl implements ExportToPathOnHostResponse {
+    }
+    
+    public ExportToPathOnHostRequest exportToPathOnHost() {
+        return new ExportToPathOnHostRequestImpl();
+    }
+    
     private class UndoSnapshotRequestImpl extends BaseRequest<UndoSnapshotRequest, UndoSnapshotResponse> implements UndoSnapshotRequest {
         private Boolean async;
         public UndoSnapshotRequest async(Boolean async) {
@@ -1334,7 +1548,9 @@ public class VmServiceImpl extends ServiceImpl implements VmService {
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new UpdateResponseImpl(XmlVmReader.readOne(reader));
+                    UpdateResponseImpl actionResponse = new UpdateResponseImpl();
+                    actionResponse.vm(XmlVmReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -1345,7 +1561,7 @@ public class VmServiceImpl extends ServiceImpl implements VmService {
             }
             else {
                 checkFault(response);
-                return new UpdateResponseImpl(null);
+                return new UpdateResponseImpl();
             }
         }
         
@@ -1354,7 +1570,7 @@ public class VmServiceImpl extends ServiceImpl implements VmService {
     private class UpdateResponseImpl implements UpdateResponse {
         private Vm vm;
         
-        public UpdateResponseImpl(Vm vm) {
+        public void vm(Vm vm) {
             this.vm = vm;
         }
         
