@@ -157,6 +157,9 @@ public class XmlTemplateReader {
                 case "permissions":
                 object.permissions(XmlPermissionReader.readMany(reader));
                 break;
+                case "placement_policy":
+                object.placementPolicy(XmlVmPlacementPolicyReader.readOne(reader));
+                break;
                 case "quota":
                 object.quota(XmlQuotaReader.readOne(reader));
                 break;
