@@ -120,27 +120,36 @@ public interface OpenstackVolumeProvidersService extends Service {
     /**
      * Retrieves the list of volume providers.
      * 
-     * The order of the returned list of volume providers isn't guaranteed.
+     * The order of the returned list of volume providers is not guaranteed.
      */
     public interface ListRequest extends Request<ListRequest, ListResponse> {
         /**
-         * Sets the maximum number of providers to return. If not specified all the providers are returned.
+         * Indicates which inner links should be _followed_. The objects referenced by these links will be fetched as part
+         * of the current request. See <<documents/003_common_concepts/follow, here>> for details.
+         */
+        ListRequest follow(String follow);
+        /**
+         * Sets the maximum number of providers to return. If not specified, all the providers are returned.
          */
         ListRequest max(Integer max);
         /**
-         * Sets the maximum number of providers to return. If not specified all the providers are returned.
+         * Sets the maximum number of providers to return. If not specified, all the providers are returned.
          */
         ListRequest max(Long max);
         /**
-         * Sets the maximum number of providers to return. If not specified all the providers are returned.
+         * Sets the maximum number of providers to return. If not specified, all the providers are returned.
          */
         ListRequest max(BigInteger max);
+        /**
+         * A query string used to restrict the returned volume providers.
+         */
+        ListRequest search(String search);
     }
     
     /**
      * Retrieves the list of volume providers.
      * 
-     * The order of the returned list of volume providers isn't guaranteed.
+     * The order of the returned list of volume providers is not guaranteed.
      */
     public interface ListResponse extends Response {
         List<OpenStackVolumeProvider> providers();
@@ -149,7 +158,7 @@ public interface OpenstackVolumeProvidersService extends Service {
     /**
      * Retrieves the list of volume providers.
      * 
-     * The order of the returned list of volume providers isn't guaranteed.
+     * The order of the returned list of volume providers is not guaranteed.
      */
     ListRequest list();
     
