@@ -15,29 +15,48 @@ limitations under the License.
 
 package org.ovirt.engine.sdk4.types;
 
-
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+/**
+ * Defines the values for the IP protocol version.
+ */
 public enum IpVersion {
+    /**
+     * IPv4.
+     */
+    V4("v4"),
+    /**
+     * IPv6.
+     */
+    V6("v6"),
+    ;
     
-    V4,
-    V6;
+    private static final Logger log = LoggerFactory.getLogger(IpVersion.class);
     
-    private static final Logger LOG = LoggerFactory.getLogger(IpVersion.class);
+    private String image;
+    
+    IpVersion(String image) {
+        this.image = image;
+    }
     
     public String value() {
-        return name().toLowerCase();
+        return image;
     }
     
     public static IpVersion fromValue(String value) {
         try {
             return valueOf(value.toUpperCase());
         }
-        catch (IllegalArgumentException e) {
-            LOG.error("The string '" + value + "' isn't a valid value for the 'IpVersion' enumerated type. Valid values are: 'v4', 'v6'.");
+        catch (IllegalArgumentException exception) {
+            log.error(
+            "The string '" + value + "' isn't a valid value for the 'IpVersion' enumerated type. " +
+            "Valid values are 'v4' and 'v6'.",
+            exception
+            );
             return null;
         }
     }
     
 }
+
