@@ -15,29 +15,39 @@ limitations under the License.
 
 package org.ovirt.engine.sdk4.types;
 
-
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 public enum NetworkStatus {
+    NON_OPERATIONAL("non_operational"),
+    OPERATIONAL("operational"),
+    ;
     
-    OPERATIONAL,
-    NON_OPERATIONAL;
+    private static final Logger log = LoggerFactory.getLogger(NetworkStatus.class);
     
-    private static final Logger LOG = LoggerFactory.getLogger(NetworkStatus.class);
+    private String image;
+    
+    NetworkStatus(String image) {
+        this.image = image;
+    }
     
     public String value() {
-        return name().toLowerCase();
+        return image;
     }
     
     public static NetworkStatus fromValue(String value) {
         try {
             return valueOf(value.toUpperCase());
         }
-        catch (IllegalArgumentException e) {
-            LOG.error("The string '" + value + "' isn't a valid value for the 'NetworkStatus' enumerated type. Valid values are: 'operational', 'non_operational'.");
+        catch (IllegalArgumentException exception) {
+            log.error(
+            "The string '" + value + "' isn't a valid value for the 'NetworkStatus' enumerated type. " +
+            "Valid values are 'non_operational' and 'operational'.",
+            exception
+            );
             return null;
         }
     }
     
 }
+
